@@ -622,6 +622,7 @@ typedef struct
 }			PGVersion;
 
 extern ProcessState processState;
+extern bool	reset_query_error;	/* true if error occurs in reset queries */
 
 extern POOL_CONNECTION_POOL * pool_connection_pool; /* connection pool */
 extern volatile sig_atomic_t backend_timer_expired; /* flag for connection
@@ -806,7 +807,7 @@ extern PGVersion *Pgversion(POOL_CONNECTION_POOL * backend);
 extern void reset_variables(void);
 extern void reset_connection(void);
 extern void per_node_statement_log(POOL_CONNECTION_POOL * backend, int node_id, char *query);
-extern void per_node_error_log(POOL_CONNECTION_POOL * backend, int node_id, char *query, char *prefix, bool unread);
+extern char per_node_error_log(POOL_CONNECTION_POOL * backend, int node_id, char *query, char *prefix, bool unread);
 extern int	pool_extract_error_message(bool read_kind, POOL_CONNECTION * backend, int major, bool unread, char **message);
 extern POOL_STATUS do_command(POOL_CONNECTION * frontend, POOL_CONNECTION * backend,
 							  char *query, int protoMajor, int pid, int key, int no_ready_for_query);
